.. index:: pair: adding; person

Adding people
-------------

There are two ways of adding a new person to Karaage. One is that the person
accesses Karaage, and places a request to join a project or create a new
project. This request must then be approved by the project leader (existing
project), or institute delegate (new project), and a system administrator.

The other way is for a system administrator to add the person in Karaage.

If you are an administrator and want to add a person:

#.  Check there is an institute appropriate for the person, under Institutes.
    If not, add an institute.
#.  If person is to join a project, check the project already exists, under
    Projects. If not, add the project.
#.  Check if the person already exists, under People. If not, add the person.
